==> libmaa_1.4.4.orig.tar.gz: libmaa-1.4.4/tests/log/logtest.c <==
/* sltest.c -- 
 * Created: Fri, 27 Feb 2009 23:21:31 +0200 by vle@gmx.net
 * Copyright 2009 Aleksey Cheusov (vle@gmx.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#include "maaP.h"

int main( int argc, char **argv )
{
   const char *logfn;

   --argc, ++argv;

   if (!argc)
      return 1;

   logfn = argv [0];

   maa_init (argv [0]);

   log_file ("logtest", logfn);

   log_error ("main", "Error??? No-o-o-o... :-)");

   maa_shutdown ();

   return 0;
}

==> libmaa_1.5.1.orig.tar.gz: libmaa-1.5.1/tests/log/logtest.c <==
/* sltest.c -- 
 * Created: Fri, 27 Feb 2009 23:21:31 +0200 by vle@gmx.net
 * Copyright 2009 Aleksey Cheusov (vle@gmx.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#include "maaP.h"

int main(int argc, char **argv)
{
	const char *logfn;

	--argc, ++argv;

	if (!argc)
		return 1;

	logfn = argv[0];

	maa_init(argv[0]);

	log_file("logtest", logfn);

	log_error("main", "Error??? No-o-o-o... :-)");

	log_set_facility("syslog");
	log_error("main", "log_facility: %s", log_get_facility());
	log_info("five: %d", 5);

	log_syslog("ident");
	log_syslog(NULL);

	log_close();

	maa_shutdown();

	return 0;
}
